##############################################################################
# This procedure is called when a new shape needs to be selected.  This can  #
# be when a new item has just been created, then the shape is automatically  #
# selected for modification.  Or if the user selects an item, this procedure #
# is called once the item has been identified in order to select it.         #
##############################################################################
proc Auto_Select {Currentitem} {

    global _NITEM
    global _Force_Annotation

# Remove the tag 'selected' from any items on the canvas, and remove its
# bounding-box.
    .can.c1 dtag selected
    .can.c1 delete boundingbox selpt pts$_NITEM

# Add tag 'selected' to the last drawn shape
    .can.c1 addtag selected withtag $Currentitem

# Create a list to hold the coordinates of an approximate bounding-box for
# the selected shape
    set edges [.can.c1 bbox selected]

# Index these and set variables to hold the values, so points can be placed
# around the edge of the box
    set x1 [lindex $edges 0]
    set y1 [lindex $edges 1]
    set x2 [lindex $edges 2]
    set y2 [lindex $edges 3]

# Calculations to find positions half way along box edges.
# The catch command is used to trap the error if this command is executed
# without the relevant parameters
    catch {set mx [expr ($x1+($x2-$x1)/2)]}
    catch {set my [expr ($y1+($y2-$y1)/2)]}

# Create a bounding-box for the new shape, and draw it
    eval ".can.c1 create rectangle $edges -outline purple -tags boundingbox"

# Create points around the box, giving each point a universal and an
# individual tags. Universal tag required for choosing to scale the item.
# Individual tag required to identify plane(s) to scale in
    eval ".can.c1 create rectangle $x1 $y1 $x1 $y1 -width 5 \
        -outline green -tags selpt1"
    .can.c1 addtag selpt withtag selpt1

    eval ".can.c1 create rectangle $mx $y1 $mx $y1 -width 5 \
        -outline green -tags selpt2"
    .can.c1 addtag selpt withtag selpt2

    eval ".can.c1 create rectangle $x2 $y1 $x2 $y1 -width 5 \
        -outline green -tags selpt3"
    .can.c1 addtag selpt withtag selpt3

    eval ".can.c1 create rectangle $x1 $my $x1 $my -width 5 \
        -outline green -tags selpt4"
    .can.c1 addtag selpt withtag selpt4

    eval ".can.c1 create rectangle $x2 $my $x2 $my -width 5 \
        -outline green -tags selpt5"
    .can.c1 addtag selpt withtag selpt5

    eval ".can.c1 create rectangle $x1 $y2 $x1 $y2 -width 5 \
        -outline green -tags selpt6"
    .can.c1 addtag selpt withtag selpt6

    eval ".can.c1 create rectangle $mx $y2 $mx $y2 -width 5 \
        -outline green -tags selpt7"
    .can.c1 addtag selpt withtag selpt7

    eval ".can.c1 create rectangle $x2 $y2 $x2 $y2 -width 5 \
        -outline green -tags selpt8"
    .can.c1 addtag selpt withtag selpt8


# If this procedure is called to select a shape just created, 'Currentitem' 
# will be identical to string "item$_NITEM".
# If so, then '_NITEM' needs to be incremented to give individual tags
    if {$Currentitem=="item$_NITEM"} {
        incr _NITEM
# if we have force annotation, call the annotater here
        if {$_Force_Annotation == 1} {
            Annotate_Selected
        }
    }
# we can swicth on the Test_URL (if there is a selected object with valid URL)
    if {[getURLOfSelected] != ""} {
        .can.menu.test configure -state normal
    }
}
