#____________________________________________________________________________#
#|                                                                          |#
#| This file contains procedures to create the bindings allowing the user   |#
#| to create polygons.  Curvagons have been removed for now as the server   |#
#| does not recognise these and they would have to be seen as polygons.     |#
#| This could lead to discrepancies between the created map, and the        |#
#| final output.                                                            |#
#| The procedures in this file are called when one of the "Create_poly"     |#
#| options is selected.  They remain through one complete creation and then |#
#| are reset to the Default.                                                |#
#| 1. proc Create_Poly_BP1 :                                                |#
#|         Set the binding for <ButtonPress-1>.  On each successive button- |#
#|         press, a new point is created for the polygon at the current x,y |#
#|         location of the cursor, and a line joining together the points   |#
#|         is drawn.                                                        |#
#| 2. proc Create_Poly_BP2 :                                                |#
#|         Set the binding for <ButtonPress-2>.  If the polygon being       |#
#|         created has less than Three points when button-2 is pressed, a   |#
#|         message will be displayed advising the user of his options.      |#
#|         Otherwise the polygon will be closed and drawn.                  |#
#|__________________________________________________________________________|#
#                                                                            #

#============================================================================#

proc Create_Poly_BP1 {} {

# There is no need for any bindings for Button-release-1.  Set to NULL
    bind .can.c1 <ButtonRelease-1> {}
    bind .can.c1 <B1-Motion> {}

    bind .can.c1 <ButtonPress-1> {

# Remove any previously drawn lines indicating the shape
        .can.c1 delete outline

# If first point, set list 'line' containing coordinates of poly to empty,
# else create a line passing through each point on the polygon.
        if {$_NPOINTS==0} {
            set line ""
        } else {
            eval ".can.c1 create line $line \
                [.can.c1 canvasx %x] [.can.c1 canvasy %y] \
                -fill $_COLOUR -tags outline"
	}

# Increment "_NPOINTS so it holds the number of elements in coordinate list
        incr _NPOINTS 2

# Append list to contain new coordinates for poly
        set line [concat $line [.can.c1 canvasx %x] [.can.c1 canvasy %y]]
    }
}

#============================================================================#

proc Create_Poly_BP2 {} {

    bind .can.c1 <Button-2> {
        if {$_NPOINTS!=0} {

            if {$_NPOINTS<4} {
                set message "\n\nPolygon must have 3 or more points."
                Set_Message $message
	    } else {
# Deletes the outline of the poly
                .can.c1 delete outline

# Append the list, and create poly
                set line [concat $line \
                    [.can.c1 canvasx %x] [.can.c1 canvasy %y]]
                set lastpts [lrange $line 0 1]

                if {$_STYLE=="outline"} {
                    eval ".can.c1 create line $line $lastpts -fill $_COLOUR \
                        -width $_LINE_WIDTH -tags item$_NITEM"
		} else {
                    eval ".can.c1 create polygon $line  -fill $_COLOUR \
                        -tags item$_NITEM"
                }
# Invoke the procedure to append the global list of attributes
                Item_Tags list item$_NITEM

                .can.c1 addtag $list withtag item$_NITEM

# Give the previously selected shape the tag "item" so it can be reselected
                .can.c1 addtag item withtag selected
# Call procedure to automatically select the new item
                Auto_Select item$_NITEM

# Reset the radiobutton variable to empty
                set _CHOICE ""

# Call to procedure to reset default bindings
                Control ""
	    }
	}
    }
}
