##############################################################################
# Create the bindings allowing the user to flip the selected item.           #
# Invoked with R-buttons from "Options" window. Two possible choices :       #
#       1. Flip around a horizontal axis. (FLIP_ABOUT-Y)                     #
#       2. Flip around a vertical axis.   (FLIP_ABOUT-X)                     #
# This option is selected by pressing the appropriate radiobutton, then      #
# <BP-1> in one of the points on the bounding-box of the selected item.  The #
# "flip" is executed using the x,y coordinates of the cursor as a centre.    #
##############################################################################
proc Flip_Item {} {

# If no item is currently selected, then tags will be a null string.
# To avoid getting caught in that binding, display a message for the user,
# and then reset to the default bindings allowing a shape to be selected. 
# If tags is not empty, then create the bindings allowing the selected shape
# to be flipped.
    set tags [.can.c1 gettags selected]

    if {$tags==""} {
        set msg "\nThere is currently no selected item. Select one and try again."
        Set_Message $msg

# Display the message for some time before resetting the default bindings
        after 2500 {Control ""}

    } else {

# If <BP-1> while cursor is in selpt, calculate the new coordinates for
# each point
        .can.c1 bind selpt <ButtonPress-1> {
            set Scaling 0
            set Move_motion 0

# Set a list to hold coordinates of the item, and a variable to contain number 
# of elements in list.  This is used to step through the coordinates and alter
# the relevant values.
            set coords [.can.c1 coords selected]
            set lengthCoords [llength $coords]

# If left-right flip is selected, only x-coordinates need altering.
# If up-down flip is selected, only y-coordinates need altering.
            if {$_CHOICE=="FLIP_ABOUT-X"} {
                set mirror_x [.can.c1 canvasx %x]
                for {set a 0} {$a<$lengthCoords} {incr a 2} {
                    set new_x [expr ($mirror_x+($mirror_x-[lindex $coords $a]))]
                    set coords [lreplace $coords $a $a $new_x]
	        }
	    }
            if {$_CHOICE=="FLIP_ABOUT-Y"} {
                set mirror_y [.can.c1 canvasy %y]
                for {set a 1} {$a<$lengthCoords} {incr a 2} {
                    set new_y [expr ($mirror_y+($mirror_y-[lindex $coords $a]))]
                    set coords [lreplace $coords $a $a $new_y]
                }
            }
#------------------------------------------------------------------------------#
# The remainder of the code is the same no-matter which option has been        #
# selected.  The "if" statement has been included because the                  #
#<sequence_of_events> is identical to that which selects an item for "Scaling".#
# In case this remains as a rogue-binding, the if statement ensures it is only #
# executed if the radio-button for the action is on.                           #
#------------------------------------------------------------------------------#
            if {$_CHOICE=="FLIP_ABOUT-X" || $_CHOICE=="FLIP_ABOUT-Y"} {
# Find the type of the item
                set type [.can.c1 type selected]
# Get a list of all tags for the item
                set taglist [.can.c1 gettags selected]

# Set variable to hold tag 'itemindex'
                set itemIndex [lindex $taglist 0]
# Get the "attributes" of the selected item in a list
                set attributes [lindex $taglist 1]
# Set relevant variables according to this list
                set itemColour [lindex $attributes 1]
                set itemWidth [lindex $attributes 2]

# Delete the old item and create its mirror-image from the acquired information
                .can.c1 delete selected boundingbox selpt

# Dependant on the item-attributes, create its mirror-image
                if {$_STYLE=="outline"} {
                    if {$type=="line"} {
                        eval ".can.c1 create $type $coords \
                            -fill $itemColour -width $itemWidth \
                            -tags $itemIndex"
		    } else {
		        eval ".can.c1 create $type $coords \
                            -outline $itemColour -width $itemWidth \
                            -tags $itemIndex"
                    }
                } else {
                    if {$type=="polygon"} {
                        eval ".can.c1 create $type $coords \
                            -fill $itemColour -tags $itemIndex"
                    } else {
                        eval ".can.c1 create $type $coords 
                            -fill $itemColour -outline {} -tags $itemIndex"
                    }
                }

# A new item has been created, so tags must be inserted in the correct order
                .can.c1 dtag $itemIndex selected
                .can.c1 dtag $itemIndex item

                .can.c1 addtag $attributes withtag $itemIndex
            }
            .can.c1 addtag selected withtag $itemIndex
            set _CHOICE ""
# This binding is used to scale items.  So, any other bindings must
# be deleted.  Procedure 'auto_select' calls the procedure to reset
# the default binding to scale items
            .can.c1 bind selpt <Enter> {}
        }

# Set <BR-1> to call "proc Control".  This resets to the default bindings.
        bind .can.c1 <ButtonRelease-1> {
            Auto_Select $itemIndex
            Control ""
        }
    }
}
